@@ -3,9 +3,6 @@
 Run and monitor celery tasks
 """
 
-from six import text_type
-_ = text_type
-
 
 class _States(object):
     """ Helper class to create customizable state "lists". Each state is
@@ -21,8 +18,6 @@ class _States(object):
         return hasattr(self, item)
 
 
-STATES = _States(_('PENDING'), _('STARTED'), _('SUCCESS'),
-                 _('FAILURE'), _('REVOKED'))
+STATES = _States('PENDING', 'STARTED', 'SUCCESS', 'FAILURE', 'REVOKED')
 
-
-FINAL_STATES = _States(_('SUCCESS'), _('FAILURE'), _('REVOKED'))
+FINAL_STATES = _States('SUCCESS', 'FAILURE', 'REVOKED')
