@@ -25,11 +25,11 @@ from logilab.mtconverter import xml_escape
 
 from cubicweb import tags
 from cubicweb.entities.adapters import ITreeAdapter
-from cubicweb.view import EntityView
+from cubicweb_web.view import EntityView
 from cubicweb.predicates import is_instance, match_view, adaptable
-from cubicweb.web.views import uicfg, tabs
-from cubicweb.web.views.cwsources import LogTable, LogTableLayout
-from cubicweb.web.views.json import JsonMixIn
+from cubicweb_web.views import uicfg, tabs
+from cubicweb_web.views.cwsources import LogTable, LogTableLayout
+from cubicweb_web.views.json import JsonMixIn
 
 from cubicweb_celerytask import STATES
 
